@@ -154,7 +154,7 @@ msgid "Some msgstr with "double\" quotes"
             self.fail("Unescaped quote not detected")
         except IOError:
             exc = sys.exc_info()[1]
-            msg = 'Syntax error in po file None (line 3): unescaped double quote found'
+            msg = 'Syntax error in po file (line 3): unescaped double quote found'
             self.assertEqual(str(exc), msg)
 
     def test_unescaped_double_quote2(self):
@@ -171,7 +171,7 @@ msgstr ""
             self.fail("Unescaped quote not detected")
         except IOError:
             exc = sys.exc_info()[1]
-            msg = 'Syntax error in po file None (line 4): unescaped double quote found'
+            msg = 'Syntax error in po file (line 4): unescaped double quote found'
             self.assertEqual(str(exc), msg)
 
     def test_unescaped_double_quote3(self):
@@ -187,7 +187,7 @@ msgid ""Some msgstr with double\" quotes"
             self.fail("Unescaped quote not detected")
         except IOError:
             exc = sys.exc_info()[1]
-            msg = 'Syntax error in po file None (line 3): unescaped double quote found'
+            msg = 'Syntax error in po file (line 3): unescaped double quote found'
             self.assertEqual(str(exc), msg)
 
     def test_unescaped_double_quote4(self):
@@ -204,7 +204,7 @@ msgstr ""
             self.fail("Unescaped quote not detected")
         except IOError:
             exc = sys.exc_info()[1]
-            msg = 'Syntax error in po file None (line 4): unescaped double quote found'
+            msg = 'Syntax error in po file (line 4): unescaped double quote found'
             self.assertEqual(str(exc), msg)
     
     def test_detect_encoding1(self):
@@ -304,15 +304,15 @@ msgstr ""
 
     def test_linenum_1(self):
         po = polib.pofile('tests/test_utf8.po')
-        self.assertEqual(po[0].linenum, 18)
+        self.assertEqual(po[0].linenum, 17)
 
     def test_linenum_2(self):
         po = polib.pofile('tests/test_utf8.po')
-        self.assertEqual(po.find('XML text').linenum, 1799)
+        self.assertEqual(po.find('XML text').linenum, 1798)
 
     def test_linenum_3(self):
         po = polib.pofile('tests/test_utf8.po')
-        self.assertEqual(po[-1].linenum, 3478)
+        self.assertEqual(po[-1].linenum, 3477)
 
     def test_windows_path_occurrences(self):
         po = polib.pofile('tests/test_weird_occurrences.po')
@@ -389,6 +389,13 @@ class TestBaseFile(unittest.TestCase):
         self.assertEqual(entry1.msgstr, u('test context 1'))
         self.assertEqual(entry2.msgstr, u('test context 2'))
 
+    def test_find5(self):
+        pofile = polib.pofile('tests/test_msgctxt.po')
+        entry1 = pofile.find('some string')
+        entry2 = pofile.find('some string', msgctxt='Some message context')
+        self.assertEqual(entry1.msgstr, u('une cha\u00eene sans contexte'))
+        self.assertEqual(entry2.msgstr, u('une cha\u00eene avec contexte'))
+
     def test_save1(self):
         pofile = polib.POFile()
         self.assertRaises(IOError, pofile.save)
@@ -661,18 +668,22 @@ msgstr "Content-Type: text/plain; charset=UTF-8\u005cn"
 
 msgctxt "Some message context"
 msgid "some string"
-msgstr "une cha\u00eene"
+msgstr "une cha\u00eene avec contexte"
 
 msgctxt "Some other message context"
 msgid "singular"
 msgid_plural "plural"
 msgstr[0] "singulier"
 msgstr[1] "pluriel"
+
+msgid "some string"
+msgstr "une cha\u00eene sans contexte"
 ''')
         self.assertEqual(mo.__unicode__(), expected)
 
     def test_invalid_version(self):
         self.assertRaises(IOError, polib.mofile, 'tests/test_invalid_version.mo')
+        polib.mofile('tests/test_version_1.1.mo')
 
     def test_no_header(self):
         mo = polib.mofile('tests/test_no_header.mo')
